Learn R Programming

hdi (version 0.1-6)

lasso.cv: Select Predictors via (10-fold) Cross-Validation of the Lasso

Description

Performs (n-fold) cross-validation of the lasso (via cv.glmnet) and determines the prediction optimal set of parameters.

Usage

lasso.cv(x, y,
         nfolds = 10,
         grouped = nrow(x) > 3*nfolds,
         …)

Arguments

x

numeric design matrix (without intercept) of dimension \(n \times p\).

y

response vector of length \(n\).

nfolds

the number of folds to be used in the cross-validation

grouped

corresponds to the grouped argument to cv.glmnet. This has a smart default such that glmnet does not give a warning about too small sample size.

…

further arguments to be passed to cv.glmnet.

Value

Vector of selected predictors.

Details

The function basically only calls cv.glmnet, see source code.

See Also

hdi which uses lasso.cv() by default; cv.glmnet. An alternative for hdi(): lasso.firstq.

Examples

Run this code
# NOT RUN {
x <- matrix(rnorm(100*1000), nrow = 100, ncol = 1000)
y <- x[,1] * 2 + x[,2] * 2.5 + rnorm(100)
sel <- lasso.cv(x, y)
sel
# }

Run the code above in your browser using DataLab